.. toctree::
   :maxdepth: 2
   :caption: Contents:

   module_docs/embody
   module_docs/embody/graphviz_template
   module_docs/embody/naming
   module_docs/embody/scrap/ca_templating
   module_docs/embody/templater
   module_docs/embody/templating
